summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/usr/local/www/status_dhcp_leases.php16
-rw-r--r--src/usr/local/www/status_dhcpv6_leases.php18
-rw-r--r--src/usr/local/www/status_filter_reload.php8
-rw-r--r--src/usr/local/www/status_graph.php35
-rw-r--r--src/usr/local/www/status_ipsec.php34
-rw-r--r--src/usr/local/www/status_ipsec_sad.php6
-rw-r--r--src/usr/local/www/status_logs.php6
-rw-r--r--src/usr/local/www/status_logs_filter.php10
-rw-r--r--src/usr/local/www/status_logs_filter_dynamic.php10
-rw-r--r--src/usr/local/www/status_logs_filter_summary.php8
-rw-r--r--src/usr/local/www/status_logs_vpn.php10
-rw-r--r--src/usr/local/www/status_openvpn.php8
-rw-r--r--src/usr/local/www/status_pkglogs.php2
-rw-r--r--src/usr/local/www/status_wireless.php6
14 files changed, 79 insertions, 98 deletions
diff --git a/src/usr/local/www/status_dhcp_leases.php b/src/usr/local/www/status_dhcp_leases.php
index bbc3b48..9df1aae 100644
--- a/src/usr/local/www/status_dhcp_leases.php
+++ b/src/usr/local/www/status_dhcp_leases.php
@@ -38,7 +38,7 @@ $shortcut_section = "dhcp";
$leasesfile = "{$g['dhcpd_chroot_path']}/var/db/dhcpd.leases";
-if (($_GET['deleteip']) && (is_ipaddr($_GET['deleteip']))) {
+if (($_POST['deleteip']) && (is_ipaddr($_POST['deleteip']))) {
/* Stop DHCPD */
killbyname("dhcpd");
@@ -49,7 +49,7 @@ if (($_GET['deleteip']) && (is_ipaddr($_GET['deleteip']))) {
$i = 0;
while ($i < count($leases_contents)) {
/* Find the lease(s) we want to delete */
- if ($leases_contents[$i] == "lease {$_GET['deleteip']} {\n") {
+ if ($leases_contents[$i] == "lease {$_POST['deleteip']} {\n") {
/* Skip to the end of the lease declaration */
do {
$i++;
@@ -68,7 +68,7 @@ if (($_GET['deleteip']) && (is_ipaddr($_GET['deleteip']))) {
/* Restart DHCP Service */
services_dhcpd_configure();
- header("Location: status_dhcp_leases.php?all={$_GET['all']}");
+ header("Location: status_dhcp_leases.php?all={$_REQUEST['all']}");
}
// Load MAC-Manufacturer table
@@ -77,7 +77,7 @@ $mac_man = load_mac_manufacturer_table();
include("head.inc");
function leasecmp($a, $b) {
- return strcmp($a[$_GET['order']], $b[$_GET['order']]);
+ return strcmp($a[$_REQUEST['order']], $b[$_REQUEST['order']]);
}
function adjust_gmt($dt) {
@@ -304,7 +304,7 @@ foreach ($config['interfaces'] as $ifname => $ifarr) {
}
}
-if ($_GET['order']) {
+if ($_REQUEST['order']) {
usort($leases, "leasecmp");
}
@@ -375,7 +375,7 @@ $iflist = get_configured_interface_with_descr(); //get interface descr for # of
$no_leases_displayed = true;
foreach ($leases as $data):
- if ($data['act'] != $active_string && $data['act'] != $static_string && $_GET['all'] != 1) {
+ if ($data['act'] != $active_string && $data['act'] != $static_string && $_REQUEST['all'] != 1) {
continue;
}
@@ -470,7 +470,7 @@ if ($got_cid) {
<?php endif; ?>
<?php if ($data['type'] == $dynamic_string && $data['online'] != $online_string):?>
- <a class="fa fa-trash" title="<?=gettext('Delete lease')?>" href="status_dhcp_leases.php?deleteip=<?=$data['ip']?>&amp;all=<?=intval($_GET['all'])?>"></a>
+ <a class="fa fa-trash" title="<?=gettext('Delete lease')?>" href="status_dhcp_leases.php?deleteip=<?=$data['ip']?>&amp;all=<?=intval($_POST['all'])?>" usepost></a>
<?php endif; ?>
</td>
</tr>
@@ -523,7 +523,7 @@ else:
</div>
</div>
-<?php if ($_GET['all']): ?>
+<?php if ($_REQUEST['all']): ?>
<a class="btn btn-info" href="status_dhcp_leases.php?all=0"><i class="fa fa-minus-circle icon-embed-btn"></i><?=gettext("Show active and static leases only")?></a>
<?php else: ?>
<a class="btn btn-info" href="status_dhcp_leases.php?all=1"><i class="fa fa-plus-circle icon-embed-btn"></i><?=gettext("Show all configured leases")?></a>
diff --git a/src/usr/local/www/status_dhcpv6_leases.php b/src/usr/local/www/status_dhcpv6_leases.php
index 1357b9f..72740a9 100644
--- a/src/usr/local/www/status_dhcpv6_leases.php
+++ b/src/usr/local/www/status_dhcpv6_leases.php
@@ -39,7 +39,7 @@ $shortcut_section = "dhcp6";
$leasesfile = "{$g['dhcpd_chroot_path']}/var/db/dhcpd6.leases";
-if (($_GET['deleteip']) && (is_ipaddr($_GET['deleteip']))) {
+if (($_POST['deleteip']) && (is_ipaddr($_POST['deleteip']))) {
/* Stop DHCPD */
killbyname("dhcpd");
@@ -49,7 +49,7 @@ if (($_GET['deleteip']) && (is_ipaddr($_GET['deleteip']))) {
$i = 0;
while ($i < count($leases_contents)) {
/* Find the lease(s) we want to delete */
- if ($leases_contents[$i] == " iaaddr {$_GET['deleteip']} {") {
+ if ($leases_contents[$i] == " iaaddr {$_POST['deleteip']} {") {
/* The iaaddr line is two lines down from the start of the lease, so remove those two lines. */
array_pop($newleases_contents);
array_pop($newleases_contents);
@@ -71,7 +71,7 @@ if (($_GET['deleteip']) && (is_ipaddr($_GET['deleteip']))) {
/* Restart DHCP Service */
services_dhcpd_configure();
- header("Location: status_dhcpv6_leases.php?all={$_GET['all']}");
+ header("Location: status_dhcpv6_leases.php?all={$_REQUEST['all']}");
}
// Load MAC-Manufacturer table
@@ -80,7 +80,7 @@ $mac_man = load_mac_manufacturer_table();
include("head.inc");
function leasecmp($a, $b) {
- return strcmp($a[$_GET['order']], $b[$_GET['order']]);
+ return strcmp($a[$_REQUEST['order']], $b[$_REQUEST['order']]);
}
function adjust_gmt($dt) {
@@ -384,7 +384,7 @@ foreach ($config['interfaces'] as $ifname => $ifarr) {
}
}
-if ($_GET['order']) {
+if ($_REQUEST['order']) {
usort($leases, "leasecmp");
}
@@ -449,7 +449,7 @@ if (!$leasesfile_found) {
<tbody>
<?php
foreach ($leases as $data):
- if ($data['act'] != $active_string && $data['act'] != $static_string && $_GET['all'] != 1) {
+ if ($data['act'] != $active_string && $data['act'] != $static_string && $_REQUEST['all'] != 1) {
continue;
}
@@ -514,7 +514,7 @@ foreach ($leases as $data):
<?php endif; ?>
<a class="fa fa-plus-square" title="<?=gettext("Add WOL mapping")?>" href="services_wol_edit.php?if=<?=$data['if']?>&amp;mac=<?=$data['mac']?>&amp;descr=<?=htmlentities($data['hostname'])?>"></a>
<?php if ($data['type'] == $dynamic_string && $data['online'] != $online_string):?>
- <a class="fa fa-trash" title="<?=gettext('Delete lease')?>" href="status_dhcpv6_leases.php?deleteip=<?=$data['ip']?>&amp;all=<?=intval($_GET['all'])?>"></a>
+ <a class="fa fa-trash" title="<?=gettext('Delete lease')?>" href="status_dhcpv6_leases.php?deleteip=<?=$data['ip']?>&amp;all=<?=intval($_REQUEST['all'])?>" usepost></a>
<?php endif; ?>
</td>
</tr>
@@ -542,7 +542,7 @@ foreach ($leases as $data):
<tbody>
<?php
foreach ($prefixes as $data):
- if ($data['act'] != $active_string && $data['act'] != $static_string && $_GET['all'] != 1) {
+ if ($data['act'] != $active_string && $data['act'] != $static_string && $_REQUEST['all'] != 1) {
continue;
}
@@ -603,7 +603,7 @@ foreach ($prefixes as $data):
</div>
</div>
-<?php if ($_GET['all']): ?>
+<?php if ($_REQUEST['all']): ?>
<a class="btn btn-info" href="status_dhcpv6_leases.php?all=0"><i class="fa fa-minus-circle icon-embed-btn"></i><?=gettext("Show active and static leases only")?></a>
<?php else: ?>
<a class="btn btn-info" href="status_dhcpv6_leases.php?all=1"><i class="fa fa-plus-circle icon-embed-btn"></i><?=gettext("Show all configured leases")?></a>
diff --git a/src/usr/local/www/status_filter_reload.php b/src/usr/local/www/status_filter_reload.php
index edc3ec4..abfaad2 100644
--- a/src/usr/local/www/status_filter_reload.php
+++ b/src/usr/local/www/status_filter_reload.php
@@ -37,7 +37,7 @@ if (file_exists("{$g['varrun_path']}/filter_reload_status")) {
$status = file_get_contents("{$g['varrun_path']}/filter_reload_status");
}
-if ($_GET['getstatus']) {
+if ($_REQUEST['getstatus']) {
echo "|{$status}|";
exit;
}
@@ -78,7 +78,7 @@ endif;
</div>
<br/>
-<?php if (!$_GET['user']) { ?>
+<?php if (!$_REQUEST['user']) { ?>
<div id="reloadinfo"><?=gettext("This page will automatically refresh every 3 seconds until the filter is done reloading."); ?></div>
<?php } ?>
@@ -161,12 +161,12 @@ if (typeof getURL == 'undefined') {
}
}
- http_request.open('GET', url, true);
+ http_request.open('REQUEST', url, true);
http_request.send(null);
}
}
-if ("<?=$_GET['user']?>" != "true") {
+if ("<?=$_REQUEST['user']?>" != "true") {
window.setTimeout('update_status_thread()', 1500);
}
//]]>
diff --git a/src/usr/local/www/status_graph.php b/src/usr/local/www/status_graph.php
index f7a3cc6..c2d2b42 100644
--- a/src/usr/local/www/status_graph.php
+++ b/src/usr/local/www/status_graph.php
@@ -52,23 +52,8 @@ foreach (array('server', 'client') as $mode) {
}
}
-// Compatiblity to restore GET parameters used pre-2.3
-// Useful to save a URL for a given graph configuration
-if (isset($_GET['if']) && !isset($_POST['if'])) {
- $_POST['if'] = $_GET['if'];
-}
-if (isset($_GET['sort']) && !isset($_POST['sort'])) {
- $_POST['sort'] = $_GET['sort'];
-}
-if (isset($_GET['filter']) && !isset($_POST['filter'])) {
- $_POST['filter'] = $_GET['filter'];
-}
-if (isset($_GET['hostipformat']) && !isset($_POST['hostipformat'])) {
- $_POST['hostipformat'] = $_GET['hostipformat'];
-}
-
-if ($_POST['if']) {
- $curif = $_POST['if'];
+if ($_REQUEST['if']) {
+ $curif = $_REQUEST['if'];
$found = false;
foreach ($ifdescrs as $descr => $ifdescr) {
if ($descr == $curif) {
@@ -89,23 +74,23 @@ if ($_POST['if']) {
$curif = "wan";
}
}
-if ($_POST['sort']) {
- $cursort = $_POST['sort'];
+if ($_REQUEST['sort']) {
+ $cursort = $_REQUEST['sort'];
} else {
$cursort = "";
}
-if ($_POST['filter']) {
- $curfilter = $_POST['filter'];
+if ($_REQUEST['filter']) {
+ $curfilter = $_REQUEST['filter'];
} else {
$curfilter = "";
}
-if ($_POST['hostipformat']) {
- $curhostipformat = $_POST['hostipformat'];
+if ($_REQUEST['hostipformat']) {
+ $curhostipformat = $_REQUEST['hostipformat'];
} else {
$curhostipformat = "";
}
-if ($_POST['backgroundupdate']) {
- $curbackgroundupdate = $_POST['backgroundupdate'];
+if ($_REQUEST['backgroundupdate']) {
+ $curbackgroundupdate = $_REQUEST['backgroundupdate'];
} else {
$curbackgroundupdate = "";
}
diff --git a/src/usr/local/www/status_ipsec.php b/src/usr/local/www/status_ipsec.php
index 0932c5f..ff07656 100644
--- a/src/usr/local/www/status_ipsec.php
+++ b/src/usr/local/www/status_ipsec.php
@@ -45,35 +45,35 @@ if ($_REQUEST['ajax']) {
exit;
}
-if ($_GET['act'] == 'connect') {
- if (ctype_digit($_GET['ikeid'])) {
- $ph1ent = ipsec_get_phase1($_GET['ikeid']);
+if ($_REQUEST['act'] == 'connect') {
+ if (ctype_digit($_REQUEST['ikeid'])) {
+ $ph1ent = ipsec_get_phase1($_REQUEST['ikeid']);
if (!empty($ph1ent)) {
if (empty($ph1ent['iketype']) || $ph1ent['iketype'] == 'ikev1' || isset($ph1ent['splitconn'])) {
- $ph2entries = ipsec_get_number_of_phase2($_GET['ikeid']);
+ $ph2entries = ipsec_get_number_of_phase2($_REQUEST['ikeid']);
for ($i = 0; $i < $ph2entries; $i++) {
- $connid = escapeshellarg("con{$_GET['ikeid']}00{$i}");
+ $connid = escapeshellarg("con{$_REQUEST['ikeid']}00{$i}");
mwexec_bg("/usr/local/sbin/ipsec down {$connid}");
mwexec_bg("/usr/local/sbin/ipsec up {$connid}");
}
} else {
- mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_GET['ikeid']));
- mwexec_bg("/usr/local/sbin/ipsec up con" . escapeshellarg($_GET['ikeid']));
+ mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_REQUEST['ikeid']));
+ mwexec_bg("/usr/local/sbin/ipsec up con" . escapeshellarg($_REQUEST['ikeid']));
}
}
}
-} else if ($_GET['act'] == 'ikedisconnect') {
- if (ctype_digit($_GET['ikeid'])) {
- if (!empty($_GET['ikesaid']) && ctype_digit($_GET['ikesaid'])) {
- mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_GET['ikeid']) . "[" . escapeshellarg($_GET['ikesaid']) . "]");
+} else if ($_REQUEST['act'] == 'ikedisconnect') {
+ if (ctype_digit($_REQUEST['ikeid'])) {
+ if (!empty($_REQUEST['ikesaid']) && ctype_digit($_REQUEST['ikesaid'])) {
+ mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_REQUEST['ikeid']) . "[" . escapeshellarg($_REQUEST['ikesaid']) . "]");
} else {
- mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_GET['ikeid']));
+ mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_REQUEST['ikeid']));
}
}
-} else if ($_GET['act'] == 'childdisconnect') {
- if (ctype_digit($_GET['ikeid'])) {
- if (!empty($_GET['ikesaid']) && ctype_digit($_GET['ikesaid'])) {
- mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_GET['ikeid']) . "{" . escapeshellarg($_GET['ikesaid']) . "}");
+} else if ($_REQUEST['act'] == 'childdisconnect') {
+ if (ctype_digit($_REQUEST['ikeid'])) {
+ if (!empty($_REQUEST['ikesaid']) && ctype_digit($_REQUEST['ikesaid'])) {
+ mwexec_bg("/usr/local/sbin/ipsec down con" . escapeshellarg($_REQUEST['ikeid']) . "{" . escapeshellarg($_REQUEST['ikesaid']) . "}");
}
}
}
@@ -227,7 +227,7 @@ function print_ipsec_body() {
if ($ikesa['state'] != 'ESTABLISHED') {
- print('<a href="status_ipsec.php?act=connect&amp;ikeid=' . $con_id . '" class="btn btn-xs btn-success" data-toggle="tooltip" title="' . gettext("Connect VPN"). '" >');
+ print('<a href="status_ipsec.php?act=connect&amp;ikeid=' . $con_id . '" class="btn btn-xs btn-success" data-toggle="tooltip" title="' . gettext("Connect VPN"). '">');
print('<i class="fa fa-sign-in icon-embed-btn"></i>');
print(gettext("Connect VPN"));
print("</a>\n");
diff --git a/src/usr/local/www/status_ipsec_sad.php b/src/usr/local/www/status_ipsec_sad.php
index 1d4ee91..7f080fd 100644
--- a/src/usr/local/www/status_ipsec_sad.php
+++ b/src/usr/local/www/status_ipsec_sad.php
@@ -41,10 +41,10 @@ include("head.inc");
$sad = ipsec_dump_sad();
/* delete any SA? */
-if ($_GET['act'] == "del") {
+if ($_POST['act'] == "del") {
$fd = @popen("/sbin/setkey -c > /dev/null 2>&1", "w");
if ($fd) {
- fwrite($fd, "delete {$_GET['src']} {$_GET['dst']} {$_GET['proto']} {$_GET['spi']} ;\n");
+ fwrite($fd, "delete {$_POST['src']} {$_POST['dst']} {$_POST['proto']} {$_POST['spi']} ;\n");
pclose($fd);
sleep(1);
}
@@ -103,7 +103,7 @@ if (count($sad)) {
$args .= "&amp;proto=" . rawurlencode($sa['proto']);
$args .= "&amp;spi=" . rawurlencode("0x" . $sa['spi']);
?>
- <a href="status_ipsec_sad.php?act=del&amp;<?=$args?>"><i class="fa fa-trash" title="<?=gettext("Remove this SPD Entry")?>"></i></a>
+ <a href="status_ipsec_sad.php?act=del&amp;<?=$args?>"><i class="fa fa-trash" title="<?=gettext("Remove this SPD Entry")?>" usepost></i></a>
</td>
</tr>
diff --git a/src/usr/local/www/status_logs_filter.php b/src/usr/local/www/status_logs_filter.php
index 6b83565..0fcd838 100644
--- a/src/usr/local/www/status_logs_filter.php
+++ b/src/usr/local/www/status_logs_filter.php
@@ -59,13 +59,13 @@ $allowed_logs = array(
"shortcut" => "filter"),
);
-// The logs to display are specified in a GET argument. Default to 'system' logs
-if (!$_GET['logfile']) {
+// The logs to display are specified in a REQUEST argument. Default to 'system' logs
+if (!$_REQUEST['logfile']) {
$logfile = 'filter';
$view = 'normal';
} else {
- $logfile = $_GET['logfile'];
- $view = $_GET['view'];
+ $logfile = $_REQUEST['logfile'];
+ $view = $_REQUEST['view'];
if (!array_key_exists($logfile, $allowed_logs)) {
/* Do not let someone attempt to load an unauthorized log. */
$logfile = 'filter';
@@ -408,7 +408,7 @@ if (typeof getURL == 'undefined') {
contentType : http_request.getResponseHeader("Content-Type") } );
}
};
- http_request.open('GET', url, true);
+ http_request.open('REQUEST', url, true);
http_request.send(null);
};
}
diff --git a/src/usr/local/www/status_logs_filter_dynamic.php b/src/usr/local/www/status_logs_filter_dynamic.php
index 7d8a85d..78ce76f 100644
--- a/src/usr/local/www/status_logs_filter_dynamic.php
+++ b/src/usr/local/www/status_logs_filter_dynamic.php
@@ -48,13 +48,13 @@ $allowed_logs = array(
"shortcut" => "filter"),
);
-// The logs to display are specified in a GET argument. Default to 'system' logs
-if (!$_GET['logfile']) {
+// The logs to display are specified in a REQUEST argument. Default to 'system' logs
+if (!$_REQUEST['logfile']) {
$logfile = 'filter';
$view = 'normal';
} else {
- $logfile = $_GET['logfile'];
- $view = $_GET['view'];
+ $logfile = $_REQUEST['logfile'];
+ $view = $_REQUEST['view'];
if (!array_key_exists($logfile, $allowed_logs)) {
/* Do not let someone attempt to load an unauthorized log. */
$logfile = 'filter';
@@ -204,7 +204,7 @@ if (typeof getURL == 'undefined') {
contentType : http_request.getResponseHeader("Content-Type") } );
}
};
- http_request.open('GET', url, true);
+ http_request.open('REQUEST', url, true);
http_request.send(null);
};
}
diff --git a/src/usr/local/www/status_openvpn.php b/src/usr/local/www/status_openvpn.php
index 0a71ac2..a3ccc70 100644
--- a/src/usr/local/www/status_openvpn.php
+++ b/src/usr/local/www/status_openvpn.php
@@ -36,10 +36,10 @@ require_once("shortcuts.inc");
require_once("service-utils.inc");
/* Handle AJAX */
-if ($_GET['action']) {
- if ($_GET['action'] == "kill") {
- $port = $_GET['port'];
- $remipp = $_GET['remipp'];
+if ($_REQUEST['action']) {
+ if ($_REQUEST['action'] == "kill") {
+ $port = $_REQUEST['port'];
+ $remipp = $_REQUEST['remipp'];
if (!empty($port) and !empty($remipp)) {
$retval = openvpn_kill_client($port, $remipp);
echo htmlentities("|{$port}|{$remipp}|{$retval}|");
diff --git a/src/usr/local/www/status_pkglogs.php b/src/usr/local/www/status_pkglogs.php
index 2317978..e18850b 100644
--- a/src/usr/local/www/status_pkglogs.php
+++ b/src/usr/local/www/status_pkglogs.php
@@ -47,7 +47,7 @@ if (!($nentries = $config['syslog']['nentries'])) {
$i = 0;
$pkgwithlogging = false;
-$apkg = $_GET['pkg'];
+$apkg = $_REQUEST['pkg'];
if (!$apkg) { // If we aren't looking for a specific package, locate the first package that handles logging.
if (isset($config['installedpackages']['package'])) {
foreach ($config['installedpackages']['package'] as $package) {
diff --git a/src/usr/local/www/status_wireless.php b/src/usr/local/www/status_wireless.php
index 4f9a73f..2edaac9 100644
--- a/src/usr/local/www/status_wireless.php
+++ b/src/usr/local/www/status_wireless.php
@@ -33,11 +33,7 @@ $shortcut_section = "wireless";
include("head.inc");
-$if = $_POST['if'];
-
-if ($_GET['if'] != "") {
- $if = $_GET['if'];
-}
+$if = $_REQUEST['if'];
$ciflist = get_configured_interface_with_descr();
if (empty($if)) {
OpenPOWER on IntegriCloud
diff --git a/src/usr/local/www/status_logs.php b/src/usr/local/www/status_logs.php
index e5d8b44..12c9c18 100644
--- a/src/usr/local/www/status_logs.php
+++ b/src/usr/local/www/status_logs.php
@@ -64,11 +64,11 @@ $allowed_logs = array(
"shortcut" => "wireless"),
);
-// The logs to display are specified in a GET argument. Default to 'system' logs
-if (!$_GET['logfile']) {
+// The logs to display are specified in a REQUEST argument. Default to 'system' logs
+if (!$_REQUEST['logfile']) {
$logfile = 'system';
} else {
- $logfile = $_GET['logfile'];
+ $logfile = $_REQUEST['logfile'];
if (!array_key_exists($logfile, $allowed_logs)) {
/* Do not let someone attempt to load an unauthorized log. */
$logfile = 'system';
diff --git a/src/usr/local/www/status_logs_filter_summary.php b/src/usr/local/www/status_logs_filter_summary.php
index bcd8a41..cf09079 100644
--- a/src/usr/local/www/status_logs_filter_summary.php
+++ b/src/usr/local/www/status_logs_filter_summary.php
@@ -41,13 +41,13 @@ $allowed_logs = array(
"shortcut" => "filter"),
);
-// The logs to display are specified in a GET argument. Default to 'system' logs
-if (!$_GET['logfile']) {
+// The logs to display are specified in a REQUEST argument. Default to 'system' logs
+if (!$_REQUEST['logfile']) {
$logfile = 'filter';
$view = 'normal';
} else {
- $logfile = $_GET['logfile'];
- $view = $_GET['view'];
+ $logfile = $_REQUEST['logfile'];
+ $view = $_REQUEST['view'];
if (!array_key_exists($logfile, $allowed_logs)) {
/* Do not let someone attempt to load an unauthorized log. */
$logfile = 'filter';
diff --git a/src/usr/local/www/status_logs_vpn.php b/src/usr/local/www/status_logs_vpn.php
index 1fd6b86..511aa29 100644
--- a/src/usr/local/www/status_logs_vpn.php
+++ b/src/usr/local/www/status_logs_vpn.php
@@ -47,13 +47,13 @@ $allowed_logs = array(
"shortcut" => "l2tps"),
);
-// The logs to display are specified in a GET argument. Default to 'system' logs
-if (!$_GET['logfile']) {
+// The logs to display are specified in a REQUEST argument. Default to 'system' logs
+if (!$_REQUEST['logfile']) {
$logfile = 'vpn';
$vpntype = "poes";
} else {
- $logfile = $_GET['logfile'];
- $vpntype = $_GET['vpntype'];
+ $logfile = $_REQUEST['logfile'];
+ $vpntype = $_REQUEST['vpntype'];
if (!array_key_exists($logfile, $allowed_logs)) {
/* Do not let someone attempt to load an unauthorized log. */
$logfile = 'vpn';
@@ -226,7 +226,7 @@ if (!$rawfilter) {
</h2>
</div>
<div class="panel-body">
- <pre><?php
+ <pre><?php
$rows = dump_clog_no_table($logfile_path, $nentries, true, array($filtertext));
?></pre>